@@ -17,9 +17,8 @@
 import os
 import re
 import sys
-import fcntl
+import platform
 import struct
-import termios
 
 from lettuce import strings
 from lettuce import core
@@ -27,6 +26,37 @@ from lettuce.terrain import after
 from lettuce.terrain import before
 
 def get_terminal_size():
+    if platform.system() == "Windows":
+        return get_terminal_size_win()
+    else:    
+        return get_terminal_size_unix()
+
+def get_terminal_size_win():
+    #Windows specific imports
+    from ctypes import windll, create_string_buffer
+    # stdin handle is -10
+    # stdout handle is -11
+    # stderr handle is -12
+    
+    h = windll.kernel32.GetStdHandle(-12)
+    csbi = create_string_buffer(22)
+    res = windll.kernel32.GetConsoleScreenBufferInfo(h, csbi)
+    
+    if res:
+        import struct
+        (bufx, bufy, curx, cury, wattr,
+         left, top, right, bottom, maxx, maxy) = struct.unpack("hhhhHhhhhhh", csbi.raw)
+        sizex = right - left + 1
+        sizey = bottom - top + 1
+    else:
+        sizex, sizey = 80, 25 # can't determine actual size - return default values
+    
+    return sizex, sizey
+
+
+def get_terminal_size_unix():
+    # Unix/Posix specific imports 
+    import fcntl, termios
     def ioctl_GWINSZ(fd):
         try:
             cr = struct.unpack('hh', fcntl.ioctl(fd, termios.TIOCGWINSZ,
@@ -50,6 +80,7 @@ def get_terminal_size():
 
     return int(cr[1]), int(cr[0])
 
+
 def wrt(what):
     sys.stdout.write(what.encode('utf-8'))
 
